@@ -13,7 +13,7 @@ import pango
 import gtk
 import hildon
 import osso
-
+import sqlite3
 
 ''' 2. Sending SMS '''
 
@@ -128,6 +128,25 @@ class SMS(object):
         print "sending sms"
     def print_pdustring(self):
         print self.pdustring
+''' x. writing to conversations '''
+def write_to_rtcomm(message, number_2):
+    connection = sqlite3.connect('/home/user/.rtcom-eventlogger/el.db')
+    cursor = connection.cursor()
+    cursor.execute('SELECT id FROM Events')
+    id_array = cursor.fetchall()  
+    seq_id = max(id_array)
+    seq_id = seq_id[0] +1
+    unixtime = int(time.time())
+    cutoff = len(number_2) -7
+    strippednumber = number_2[cutoff:]
+    dbstring = "("+str(seq_id) + ", 3, 8, " +str(unixtime)+", " + str(unixtime) +", " +str(unixtime)+", 1, 0, 0, 0, 'ring/tel/ring', '<SelfHandle>', '" + number_2 + "', 'None', '" + message +"', '"+ strippednumber +"')"
+    dbquery = "INSERT INTO Events VALUES " + dbstring
+    print dbquery
+    cursor.execute(dbquery)
+    connection.commit()
+
+
+
 
 ''' 3. Address book '''
 class _PyGObject_Functions(ctypes.Structure):
@@ -148,6 +167,13 @@ class PyGObjectCPAI(object):
 
     def pygobject_new(self, addr):
         return self._api.newgobj(addr)
+        
+
+def disable_osk(widget):
+    input_mode = widget.get_property("hildon-input-mode")
+    input_mode = input_mode | gtk.HILDON_GTK_INPUT_MODE_NO_SCREEN_PLUGINS
+    widget.set_property("hildon-input-mode", input_mode)
+
 
 window = hildon.Window()
 window.set_title("VertSMS")
@@ -156,10 +182,12 @@ receiver = hildon.TextView()
 #receiver = hildon.Entry(gtk.HILDON_SIZE_AUTO_WIDTH | 
 #                          gtk.HILDON_SIZE_THUMB_HEIGHT)
 receiver.set_placeholder("To")
+disable_osk(receiver)
 message = hildon.TextView()
 message.set_wrap_mode(gtk.WRAP_WORD)
 message.set_placeholder("Write your message here")
 message.set_cursor_visible(True)
+disable_osk(message)
 buffer = message.get_buffer()
 buffer_receiver = receiver.get_buffer()
 
@@ -170,12 +198,12 @@ last_key_pressed = None
 elapsed_time = 0
 last_update = time.time()
 
+
 capi = PyGObjectCPAI()
 #c_obj = c_function_returning_gobject(capi)
 #obj = capi.pygobject_new(c_obj)
 
-
-
+    
 def update_text(cursor_correction):
     start, end = buffer.get_bounds()
 
@@ -304,32 +332,114 @@ def backspace(empty):
   update_text(-1)
   global last_key_pressed
   last_key_pressed = None
+
+def backspace_hold(widget):
+
+  print widget.get_title()
+#  buffer.delete(buffer.get_start_iter(), buffer.get_end_iter())
+#  this needs to be done better
+#  i=0
+#  while widget.pressed():  
+#    update_text(-1)
+#    time.sleep(1)
+#    i =+1
+#    print "holded " + str(i)
   
+#''' backspace copypaste'''"
+#__init__ (self, ...):
+#    ...
+#    self.buttonReleased = True
+#    self.minimumRepeatTime = 500
+#    self.buttonDownTime = tomorrow
+#    self.repeatButtonEvent = False
+#    self.buttonPressID = 0
+#    ...
+#
+#timer_cb (self, buttonPressID):
+#    if self.buttonReleased or buttonPressID != self.buttonPressID:
+#        # stop timer forever
+#        return False
+#    if not self.repeatButtonEvent:
+#        now = getTheTime()
+#        self.repeatButtonEvent = now - self.buttonDownTime >=\
+#            self.minimumRepeatTime
+#    if not self.repeatButtonEvent:
+#        return True
+#    ...
+#    print a character
+#    ...
+#    return True
+#
+#on_button_press_event_cb (self, button, event, ...):
+#    ...
+#    self.buttonReleased = False
+#    self.buttonDownTime = event.time
+#    self.repeatButtonEvent = False
+#    self.buttonPressID = (self.buttonPressID + 1) % 0x7fffffff
+#    # I'm pretty sure this is call-by-value
+#    gobject.timeout_add(150, self.timer_cb, self.buttonPressID)
+#    ...
+#
+#on_button_release_event_cb (self, ...):
+#    ...
+#    self.buttonReleased = True
+#    ...
+#"
+#'''copypaste ends'''
+#
 def send(widget):
-    start, end = buffer.get_bounds()
-    text = buffer.get_text(start,end)
-    start2, end2 = buffer_receiver.get_bounds()
-    number = buffer_receiver.get_text(start2,end2)
-#    print "number is " +number
-    number = number.replace('+','00')
-#    print "final number is " +number    
-    if number == "":
-        note2 = "No receiver number specified!"
-        banner = hildon.hildon_banner_show_information(window,"" , note2)
-        print "error, no number specified!"
-
-    elif text == "":
-        note3 = "Message is empty!"
-        banner = hildon.hildon_banner_show_information(window,"" , note3)
-        print "error, message is empty!"
-
-    else:
-        note = "Sending message to: " + number
-        banner = hildon.hildon_banner_show_information(window,"" , note)
-        sms = SMS(text, number)
-        sms.send()
-#        sms.print_pdustring()
-
+  start, end = buffer.get_bounds()
+  text = buffer.get_text(start,end)
+  start2, end2 = buffer_receiver.get_bounds()
+  number = buffer_receiver.get_text(start2,end2)
+  number_2 = number
+  number = number.replace('+','00')
+    
+  if number == "":
+          note2 = "No receiver number specified!"
+          banner = hildon.hildon_banner_show_information(window,"" , note2)
+          print "error, no number specified!"
+  
+  elif text == "":
+          note3 = "Message is empty!"
+          banner = hildon.hildon_banner_show_information(window,"" , note3)
+          print "error, message is empty!"
+  
+  else:
+          confirm = hildon.hildon_note_new_confirmation(window, "Send message?")
+#       def show_confirmation_note(parent):
+#       note = hildon.hildon_note_new_confirmation(parent, "Do you want foo ?")
+#   
+#       response = gtk.Dialog.run(note)
+#   
+#       if response == gtk.RESPONSE_DELETE_EVENT:
+#           print "show_information_note: gtk.RESPONSE_DELETE_EVENT"
+#
+          response = gtk.Dialog.run(confirm)
+          gtk.Dialog.hide(confirm)
+          print "response was: " +str(response)
+          if response == gtk.RESPONSE_DELETE_EVENT:
+            print "sending cancelled"
+          elif response == gtk.RESPONSE_OK:
+#            start, end = buffer.get_bounds()
+#            text = buffer.get_text(start,end)
+#            start2, end2 = buffer_receiver.get_bounds()
+#            number = buffer_receiver.get_text(start2,end2)
+#        #    print "number is " +number
+#            number_2 = number
+#            number = number.replace('+','00')
+        #    print "final number is " +number    
+        
+            note = "Sending message to: " + number
+            banner = hildon.hildon_banner_show_information(window,"" , note)
+            sms = SMS(text, number)
+            sms.send()
+            write_to_rtcomm(text, number_2)
+  #        sms.print_pdustring()
+          else:
+            print "not sent"
+  
+        
 def main():
     program = hildon.Program.get_instance()
     program.add_window(window)
@@ -440,8 +550,10 @@ def main():
     table.attach(button_0, 1, 2, 7, 8)
     table.attach(button_pound, 2, 3, 7, 8)
 
+    button_back.tap_and_hold_setup(None, None, 0)
     button_send.connect("clicked", send)
     button_back.connect("clicked", backspace)
+    button_back.connect("tap-and-hold", backspace_hold)
     button_to.connect("clicked", addrbook)
     button_1.connect("clicked", number_pressed)
     button_2.connect("clicked", number_pressed)
